measuretools.scale_measure_by_multiplier_and_adjust_meter
=========================================================

.. autofunction:: abjad.tools.measuretools.scale_measure_by_multiplier_and_adjust_meter.scale_measure_by_multiplier_and_adjust_meter
